# -*- coding:utf-8 -*-
import os, ctypes, subprocess
from security_module import SecurityModule
from utils import create_file

from log import log_debug, log_error

RELABEL_FILE="/.exectl"

class ExectlModule(SecurityModule):
	status_desc = {
		"0": "关闭",
		"2": "启用(enabled)",
		"4": "启用(softmode)",
	}
	def __init__(self):
		SecurityModule.__init__(self, "exectl")

	@staticmethod
	def getstatus():
		try:
			kyseclib = ctypes.cdll.LoadLibrary("libkysec.so.0")
		except OSError as e:
			return 0
		else:
			return kyseclib.kysec_getstatus()

	@classmethod
	def do_enable(self):
		# result, error = create_file(RELABEL_FILE)
		try:
			kysec_scenelib = ctypes.cdll.LoadLibrary("libkysec_scene.so.0")
			ret = kysec_scenelib.kysec_scene_set_multi_module_status(0, 2, 0)    # 执行控制
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(1, 2, 0)    # netctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(6, 2, 0)    # devctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(13, 1, 0)   # kid
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(2, 1, 0)    # fpro
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(3, 1, 0)    # kmodctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(5, 1, 0)    # ppro
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(11, 1, 1)   # box
			if ret != 0 : return False, "设置kysec子模块状态失败"
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(10, 1, 1)   # pblk
			if ret != 0 : return False, "设置kysec子模块状态失败"
			ret |= kysec_scenelib.kysec_scene_setstatus(2, 1) # 0 关闭 2 强制模式 4 软模式； 1 永久生效   2 临时生效
			if ret != 0 : return False, "设置ksaf状态失败"

		except Exception as e:
			return (False, "libkysec_scene.so.0 打开失败")

		return (True, None)
		# if not result:
		# 	return (False, "无法创建标记文件 '%s'"%RELABEL_FILE)
		# else:
		# 	return (True, None)

	@classmethod
	def do_disable(self):
		try:
			# if os.path.exists(RELABEL_FILE):
			# 	os.unlink(RELABEL_FILE)
			#kysec_lib = ctypes.cdll.LoadLibrary("libkysec_extend.so.0")
			kysec_scenelib = ctypes.cdll.LoadLibrary("libkysec_scene.so.0")
			# kysec_lib.kysec_setstatus(4) # 0 关闭 2 强制模式 4 软模式； 1 永久生效   2 临时生效
			ret = kysec_scenelib.kysec_scene_set_multi_module_status(0, 0, 0)    # exectl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(1, 0, 0)    # netctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(2, 0, 0)    # fpro
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(3, 0, 0)    # kmodctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(5, 0, 0)    # ppro
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(6, 0, 0)    # devctl
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(10, 0, 1)   # pblk
			ret |= kysec_scenelib.kysec_scene_set_multi_module_status(13, 0, 1)   # kid
			if ret !=0 : return False, "设置kysec子模块状态失败"
			# kysec_scenelib.kysec_scene_set_module_status(11, 1)  # box  关闭时 不关闭box
			ret |= kysec_scenelib.kysec_scene_setstatus(2, 1)
			if ret !=0 : return False, "设置ksaf状态失败"
		except Exception as e:
			error = "libkysec_scene.so.0 打开失败"
			log_error("%s: %s"%(error, str(e)))
			return (False, error)
		return (True, None)

